==> webmeter-core-1.0.6-4-sources.jar: com/aote/webmeter/tools/iot/onenet/OnenetTools.java <==
package com.aote.webmeter.tools.iot.onenet;

import com.af.plugins.ConvertTools;
import com.aote.webmeter.enums.IOTExceptionCodeEnum;
import com.aote.webmeter.exception.WebmeterException;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.json.JSONObject;

import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.security.Security;

/**
 * 移动Onenet-IOT平台 基础工具
 * @author Mr.river
 */
public class OnenetTools {
    /**
     * 解密移动平台回调数据消息
     *
     * @param encodeStr 待解密的回调数据
     * @return 解密的回调数据
     */
    public static void main(String[] args) {
        decodeCallBackData("I1tdUg8Gw010eRGKyI3XpQ3IFabQq+3FNBFKDfDrhBFs6MqwsOgCB5Qq2VnD0Z3jb3cvPW2kyjFquMziosFoPke7kNwphilnntR+7pRfF6bIsu2yUynv/BeTtfyN7rnx17vAH/4ubTdZtHGjTiJP03TTXn8w15IAmyA44AIi4zg=");
    }
    public static JSONObject decodeCallBackData(String encodeStr) {
        //待解密的数据
        byte[] aesMsg = ConvertTools.base64Decode(encodeStr.getBytes(StandardCharsets.UTF_8));
        //EncodingAESKey，移动订阅时提供
        byte[] password = ConvertTools.base64Decode(("4by3wZ8xVggN1wy504aKA8OsN9Mpw5ncpI9L9G8xqKg" + "=").getBytes(StandardCharsets.UTF_8));
        //解密后的数据
        byte[] plainMsg;
        try {
            plainMsg = decrypt(aesMsg, password);
        } catch (Exception e) {
            throw new WebmeterException(IOTExceptionCodeEnum.ONENET_DECODE_CALLBACK_FAIL);
        }
        String str = new String(plainMsg, StandardCharsets.UTF_8);
        //截取JSON数据
        return new JSONObject(str.substring(str.indexOf("{")));
    }

    /**
     * AES算法解密
     *
     * @param encrypted 待解密的数据
     * @param password  解密所需的密钥
     * @return 解密的数据
     */
    private static byte[] decrypt(byte[] encrypted, byte[] password) throws Exception {
        byte[] bs = new byte[16];
        System.arraycopy(password, 0, bs, 0, 16);
        IvParameterSpec zeroIv = new IvParameterSpec(bs);
        SecretKeySpec key = new SecretKeySpec(password, "AES");
        Security.addProvider(new BouncyCastleProvider());
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS7Padding");
        cipher.init(Cipher.DECRYPT_MODE, key, zeroIv);
        return cipher.doFinal(encrypted);
    }
}

==> webmeter-core-1.0.18-rc14-sources.jar: com/aote/webmeter/tools/iot/onenet/OnenetTools.java <==
package com.aote.webmeter.tools.iot.onenet;

import com.af.plugins.ConvertTools;
import com.aote.webmeter.enums.IOTExceptionCodeEnum;
import com.aote.webmeter.exception.WebmeterException;
import com.aote.webmeter.tools.WebMeterInfo;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.json.JSONObject;

import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.security.Security;

/**
 * 移动Onenet-IOT平台 基础工具
 * @author Mr.river
 */
public class OnenetTools {
    /**
     * 解密移动平台回调数据消息
     *
     * @param encodeStr 待解密的回调数据
     * @return 解密的回调数据
     */
    public static JSONObject decodeCallBackData(String encodeStr) {
        //待解密的数据
        byte[] aesMsg = ConvertTools.base64Decode(encodeStr.getBytes(StandardCharsets.UTF_8));
        //EncodingAESKey，移动订阅时提供
        byte[] password = ConvertTools.base64Decode((WebMeterInfo.getString("onenetEncodingAESKey") + "=").getBytes(StandardCharsets.UTF_8));
        //解密后的数据
        byte[] plainMsg;
        try {
            plainMsg = decrypt(aesMsg, password);
        } catch (Exception e) {
            throw new WebmeterException(IOTExceptionCodeEnum.ONENET_DECODE_CALLBACK_FAIL);
        }
        String str = new String(plainMsg, StandardCharsets.UTF_8);
        //截取JSON数据
        return new JSONObject(str.substring(str.indexOf("{")));
    }

    /**
     * AES算法解密
     *
     * @param encrypted 待解密的数据
     * @param password  解密所需的密钥
     * @return 解密的数据
     */
    private static byte[] decrypt(byte[] encrypted, byte[] password) throws Exception {
        byte[] bs = new byte[16];
        System.arraycopy(password, 0, bs, 0, 16);
        IvParameterSpec zeroIv = new IvParameterSpec(bs);
        SecretKeySpec key = new SecretKeySpec(password, "AES");
        Security.addProvider(new BouncyCastleProvider());
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS7Padding");
        cipher.init(Cipher.DECRYPT_MODE, key, zeroIv);
        return cipher.doFinal(encrypted);
    }
}
